##  Permissions
Authentication to the MCP server is supported through API tokens that are associated with user roles. Admins configure permissions for each role to define access levels. To manage tech stacks through MCP, you need the appropriate write or edit permissions for tech stack discovery. For more details, see:
  * [Permissions for tech stacks](https://help.sap.com/docs/leanix/ea/tech-stack-discovery-from-sboms?locale=en-US&state=PRODUCTION&version=CLOUD#loio275daa577a441014b77ed8f3153809a2__section_msl_lkm_bhc)
  * [API token permissions for the MCP server](https://help.sap.com/docs/leanix/ea/connecting-to-mcp-server?locale=en-US&state=PRODUCTION&version=CLOUD#loio19c0723e588e43519756d8bebf163048__section_by2_sh4_2hc)
